@@ -41,7 +41,6 @@
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
-#include <QHostInfo>
 #include <QPointer>
 #include <QStorageInfo>
 #include <QTimer>
@@ -74,12 +73,14 @@ public:
     bool detectAllShares;
     bool longActionRunning;
     QStorageInfo storageInfo;
+    QUdpSocket udpSocket;
 };
 
 class Smb4KMounterStatic
 {
 public:
     Smb4KMounter instance;
+    const QString userMountPrefix{QStringLiteral("/var/run/smb4k/") + KUser(KUser::UseRealUserID).loginName()};
 };
 
 Q_APPLICATION_STATIC(Smb4KMounterStatic, p);
@@ -166,37 +167,28 @@ void Smb4KMounter::triggerRemounts(bool fillList)
                 continue;
             }
 
-            QList<SharePtr> mountedShares = findShareByUrl(option->url());
-            bool remountShare = true;
+            QString mountPoint = p->userMountPrefix;
+            mountPoint += QDir::separator();
+            // Host name must not be capitalized.
+            mountPoint += option->url().host();
+            mountPoint += QDir::separator();
+            mountPoint += option->url().path();
 
-            for (const SharePtr &share : std::as_const(mountedShares)) {
-                if (!share->isForeign()) {
-                    remountShare = false;
-                    break;
-                }
+            SharePtr share;
+            QDir dir(QDir::cleanPath(mountPoint));
+
+            if (!dir.canonicalPath().isEmpty()) {
+                share = findShareByPath(dir.canonicalPath());
             }
 
-            if (remountShare) {
-                bool insertShare = true;
+            if (!share) {
+                share = SharePtr(new Smb4KShare());
+                share->setUrl(option->url());
+                share->setWorkgroupName(option->workgroupName());
+                share->setHostIpAddress(option->ipAddress());
 
-                for (const SharePtr &share : std::as_const(d->remounts)) {
-                    if (QString::compare(share->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort),
-                                         option->url().toString(QUrl::RemoveUserInfo | QUrl::RemovePort))
-                        == 0) {
-                        insertShare = false;
-                        break;
-                    }
-                }
-
-                if (insertShare) {
-                    SharePtr share = SharePtr(new Smb4KShare());
-                    share->setUrl(option->url());
-                    share->setWorkgroupName(option->workgroupName());
-                    share->setHostIpAddress(option->ipAddress());
-
-                    if (share->url().isValid() && !share->url().isEmpty()) {
-                        d->remounts << share;
-                    }
+                if (share->url().isValid() && !share->url().isEmpty()) {
+                    d->remounts << share;
                 }
             }
         }
@@ -252,7 +244,6 @@ void Smb4KMounter::mountShare(const SharePtr &share)
             if (customSettings && customSettings->wakeOnLanSendBeforeMount()) {
                 Q_EMIT aboutToStart(WakeUp);
 
-                QUdpSocket *socket = new QUdpSocket(this);
                 QHostAddress addr;
 
                 // Use the host's IP address directly from the share object.
@@ -280,9 +271,7 @@ void Smb4KMounter::mountShare(const SharePtr &share)
                     }
                 }
 
-                socket->writeDatagram(sequence, addr, 9);
-
-                delete socket;
+                d->udpSocket.writeDatagram(sequence, addr, 9);
 
                 // Wait the defined time
                 int stop = 1000 * Smb4KSettings::wakeOnLANWaitingTime() / 250;
@@ -414,18 +403,18 @@ void Smb4KMounter::unmountShare(const SharePtr &share, bool silent)
     Q_ASSERT(share);
 
     if (share) {
-        //
-        // Check that the URL is valid.
-        //
         if (!share->url().isValid()) {
             Smb4KNotification::invalidURLPassed();
             return;
         }
 
-        //
+        // Foreign shares cannot be unmounted
+        if (share->isForeign()) {
+            return;
+        }
+
         // Check the mountpoint
         // Use Smb4KShare::path() here, otherwise the check will always return true.
-        //
         QFileInfo info(share->path());
         info.setCaching(false);
 
@@ -434,21 +423,8 @@ void Smb4KMounter::unmountShare(const SharePtr &share, bool silent)
             return;
         }
 
-        //
-        // Foreign shares cannot be unmounted
-        //
-        if (share->isForeign()) {
-            if (!silent) {
-                Smb4KNotification::unmountingNotAllowed(share);
-            }
-
-            return;
-        }
-
-        //
         // Force the unmounting of the share either if the system went offline
         // or if the user chose to forcibly unmount inaccessible shares (Linux only).
-        //
         bool force = false;
 
         if (Smb4KHardwareInterface::self()->isOnline()) {
@@ -461,18 +437,12 @@ void Smb4KMounter::unmountShare(const SharePtr &share, bool silent)
             force = true;
         }
 
-        //
-        // Unmount arguments
-        //
         QVariantMap args;
 
         if (!fillUnmountActionArgs(share, force, silent, args)) {
             return;
         }
 
-        //
-        // Create the unmount action
-        //
         KAuth::Action unmountAction(QStringLiteral("org.kde.smb4k.mounthelper.unmount"));
         unmountAction.setHelperId(QStringLiteral("org.kde.smb4k.mounthelper"));
         unmountAction.setArguments(args);
@@ -480,14 +450,8 @@ void Smb4KMounter::unmountShare(const SharePtr &share, bool silent)
         KAuth::ExecuteJob *job = unmountAction.execute();
         addSubjob(job);
 
-        //
-        // Emit the aboutToStart() signal
-        //
         Q_EMIT aboutToStart(UnmountShare);
 
-        //
-        // Start the job and process the returned result.
-        //
         if (job->exec()) {
             // Get the error message
             QString errorMsg = job->data().value(QStringLiteral("mh_error_message")).toString();
@@ -500,21 +464,12 @@ void Smb4KMounter::unmountShare(const SharePtr &share, bool silent)
             Smb4KNotification::actionFailed(job->error(), job->errorString());
         }
 
-        //
-        // Remove the job from the job list
-        //
         removeSubjob(job);
 
-        //
-        // Reset the busy cursor
-        //
         if (!hasSubjobs()) {
             QApplication::restoreOverrideCursor();
         }
 
-        //
-        // Emit the finished() signal
-        //
         Q_EMIT finished(UnmountShare);
     }
 }
@@ -965,17 +920,12 @@ bool Smb4KMounter::fillMountActionArgs(const SharePtr &share, int *fd, QVariantM
         map.insert(QStringLiteral("mh_homes_url"), share->url());
     }
 
-    //
-    // Kerberos ticket and process id
+    // Kerberos ticket
     //
     // The path to the Kerberos ticket is stored - if it exists - in the
     // KRB5CCNAME environment variable. By default, the ticket is located
     // at /tmp/krb5cc_[uid]. So, if the environment variable does not exist,
     // but the cache file is there, try to use it.
-    //
-    // Also, the id of the current process is needed, so that the mount helper
-    // can use the correct file descriptor.
-    //
     if (QProcessEnvironment::systemEnvironment().contains(QStringLiteral("KRB5CCNAME"))) {
         QString krb5ccFile = QProcessEnvironment::systemEnvironment().value(QStringLiteral("KRB5CCNAME")).section(QStringLiteral(":"), 1, -1);
         *fd = open(krb5ccFile.toLocal8Bit().data(), O_RDONLY);
@@ -1433,23 +1383,9 @@ void Smb4KMounter::slotConfigChanged()
 
                 check(share);
 
-                QFileInfo info(QDir::cleanPath(QStringLiteral("/var/run")));
-                info.setCaching(false);
+                QDir dir(p->userMountPrefix);
 
-                if (info.isSymLink()) {
-                    if (info.canonicalFilePath() == QDir::cleanPath(QStringLiteral("/run"))) {
-                        info.setFile(info.canonicalFilePath());
-                    } else {
-                        info.setFile(QDir::cleanPath(QStringLiteral("/run")));
-                    }
-                }
-
-                QString rootPath = info.canonicalFilePath() + QDir::separator() + QStringLiteral("smb4k");
-
-                if (share->path().startsWith(rootPath)) {
-                    share->setForeign(false);
-                } else if (share->path().startsWith(QDir::homePath())
-                           || (!share->isInaccessible() && share->canonicalPath().startsWith(QDir::home().canonicalPath()))) {
+                if (!dir.canonicalPath().isEmpty() && share->canonicalPath().startsWith(dir.canonicalPath())) {
                     share->setForeign(false);
                 } else {
                     share->setForeign(true);
@@ -1522,22 +1458,9 @@ void Smb4KMounter::slotShareMounted(const QString &mountPoint)
 
     check(share);
 
-    QFileInfo info(QDir::cleanPath(QStringLiteral("/var/run")));
-    info.setCaching(false);
+    QDir dir(p->userMountPrefix);
 
-    if (info.isSymLink()) {
-        if (info.canonicalFilePath() == QDir::cleanPath(QStringLiteral("/run"))) {
-            info.setFile(info.canonicalFilePath());
-        } else {
-            info.setFile(QDir::cleanPath(QStringLiteral("/run")));
-        }
-    }
-
-    QString rootPath = info.canonicalFilePath() + QDir::separator() + QStringLiteral("smb4k");
-
-    if (share->path().startsWith(rootPath)) {
-        share->setForeign(false);
-    } else if (share->path().startsWith(QDir::homePath()) || (!share->isInaccessible() && share->canonicalPath().startsWith(QDir::home().canonicalPath()))) {
+    if (!dir.canonicalPath().isEmpty() && share->canonicalPath().startsWith(dir.canonicalPath())) {
         share->setForeign(false);
     } else {
         share->setForeign(true);
