@@ -10,12 +10,10 @@
 #include "../core/smb4kglobal.h"
 
 // Qt includes
-#include <QDBusUnixFileDescriptor>
 #include <QDebug>
-#include <QFileInfo>
+#include <QDir>
 #include <QNetworkInterface>
 #include <QProcessEnvironment>
-#include <QStorageInfo>
 #include <QUrl>
 
 // KDE includes
@@ -27,67 +25,40 @@
 // system includes
 #include <fcntl.h>
 #include <sys/stat.h>
-#if defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
-#include <sys/mount.h>
-#include <sys/param.h>
-#include <sys/ucred.h>
-#endif
 
 using namespace Smb4KGlobal;
 
 KAUTH_HELPER_MAIN("org.kde.smb4k.mounthelper", Smb4KMountHelper);
 
-static const QStringList MOUNT_ARG_WHITELIST {
-    QStringList {
+static const QStringList MOUNT_ARG_WHITELIST{QStringList{
 #if defined(Q_OS_LINUX)
-        QStringLiteral("domain"),
-        QStringLiteral("ip"),
-        QStringLiteral("username"),
-        QStringLiteral("guest"),
-        QStringLiteral("netbiosname"),
-        QStringLiteral("servern"),
-        QStringLiteral("file_mode"),
-        QStringLiteral("dir_mode"),
-        QStringLiteral("forceuid"),
-        QStringLiteral("forcegid"),
-        QStringLiteral("iocharset"),
-        QStringLiteral("rw"),
-        QStringLiteral("ro"),
-        QStringLiteral("perm"),
-        QStringLiteral("noperm"),
-        QStringLiteral("setuids"),
-        QStringLiteral("nosetuids"),
-        QStringLiteral("serverino"),
-        QStringLiteral("noserverino"),
-        QStringLiteral("cache"),
-        QStringLiteral("mapchars"),
-        QStringLiteral("nomapchars"),
-        QStringLiteral("nobrl"),
-        QStringLiteral("sec"),
-        QStringLiteral("vers")
+    QStringLiteral("domain"),      QStringLiteral("ip"),         QStringLiteral("username"),    QStringLiteral("guest"),
+    QStringLiteral("netbiosname"), QStringLiteral("servern"),    QStringLiteral("file_mode"),   QStringLiteral("dir_mode"),
+    QStringLiteral("forceuid"),    QStringLiteral("forcegid"),   QStringLiteral("iocharset"),   QStringLiteral("rw"),
+    QStringLiteral("ro"),          QStringLiteral("perm"),       QStringLiteral("noperm"),      QStringLiteral("setuids"),
+    QStringLiteral("nosetuids"),   QStringLiteral("serverino"),  QStringLiteral("noserverino"), QStringLiteral("cache"),
+    QStringLiteral("mapchars"),    QStringLiteral("nomapchars"), QStringLiteral("nobrl"),       QStringLiteral("sec"),
+    QStringLiteral("vers")
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
-        QStringLiteral("-E"),
-        QStringLiteral("-I"),
-        QStringLiteral("-L"),
-        QStringLiteral("-N"),
-        QStringLiteral("-U"),
-        QStringLiteral("-W"),
-        QStringLiteral("-f"),
-        QStringLiteral("-d")
+    QStringLiteral("-E"),
+    QStringLiteral("-I"),
+    QStringLiteral("-L"),
+    QStringLiteral("-N"),
+    QStringLiteral("-U"),
+    QStringLiteral("-W"),
+    QStringLiteral("-f"),
+    QStringLiteral("-d")
 #endif
-    }
-};
+}};
 
-static const QStringList UNMOUNT_ARG_WHITELIST {
-    QStringList {
+static const QStringList UNMOUNT_ARG_WHITELIST{QStringList{
 #if defined(Q_OS_LINUX)
-        QStringLiteral("-l"),
-        QStringLiteral("--lazy")
+    QStringLiteral("-l"),
+    QStringLiteral("--lazy")
 #elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
-        QStringLiteral("-f")
+    QStringLiteral("-f")
 #endif
-    }
-};
+}};
 
 KAuth::ActionReply Smb4KMountHelper::mount(const QVariantMap &args)
 {
@@ -181,7 +152,7 @@ KAuth::ActionReply Smb4KMountHelper::mount(const QVariantMap &args)
         while (proc.state() != KProcess::NotRunning) {
             // We want to be able to terminate the process from outside.
             // Thus, we implement a loop that checks periodically, if we
-            // need to kill the process.
+            // need to kill the process. It is non-blocking.
             if (HelperSupport::isStopped() || timeout == 30000) {
                 proc.kill();
                 break;
@@ -258,7 +229,7 @@ KAuth::ActionReply Smb4KMountHelper::unmount(const QVariantMap &args)
         if (proc.waitForStarted(-1)) {
             // We want to be able to terminate the process from outside.
             // Thus, we implement a loop that checks periodically, if we
-            // need to kill the process.
+            // need to kill the process. It is non-blocking.
             int timeout = 0;
 
             while (proc.state() != KProcess::NotRunning) {
@@ -305,11 +276,11 @@ bool Smb4KMountHelper::isOnline() const
 
 bool Smb4KMountHelper::checkMountArguments(QStringList *argList) const
 {
-#if defined(Q_OS_LINUX)
     QStringListIterator it(*argList);
 
     while (it.hasNext()) {
         QString entry = it.next();
+#if defined(Q_OS_LINUX)
         QString arg;
 
         // Do not allow commata in an entry. We do not want a
@@ -348,13 +319,7 @@ bool Smb4KMountHelper::checkMountArguments(QStringList *argList) const
                 return false;
             }
         }
-    }
 #elif defined(Q_OS_FREEBSD) | defined(Q_OS_NETBSD)
-    QStringListIterator it(*argList);
-
-    while (it.hasNext()) {
-        QString entry = it.next();
-
         if (!entry.startsWith(QStringLiteral("-"))) {
             // These can only be arguments of the options
             continue;
@@ -387,8 +352,8 @@ bool Smb4KMountHelper::checkMountArguments(QStringList *argList) const
                 return false;
             }
         }
-    }
 #endif
+    }
 
     return true;
 }
@@ -473,26 +438,9 @@ std::optional<QString> Smb4KMountHelper::createMountPoint(const QUrl &url) const
 
 void Smb4KMountHelper::removeMountPoint(const QString &mountPoint) const
 {
-    QDir dir;
-    QString prefix = mountPrefix();
-
-    // Try to remove everything up to the mount root directory.
-    if (mountPoint.startsWith(prefix) && dir.cd(mountPoint)) {
-        dir.rmdir(dir.canonicalPath());
-
-        while (true) {
-            if (dir.cdUp()) {
-                if (dir.canonicalPath() != prefix) {
-                    if (!dir.rmdir(dir.canonicalPath())) {
-                        break;
-                    }
-                } else {
-                    break;
-                }
-            } else {
-                break;
-            }
-        }
+    if (isMountPointAllowed(mountPoint)) {
+        QDir dir;
+        dir.rmpath(mountPoint);
     }
 }
 
@@ -505,42 +453,7 @@ bool Smb4KMountHelper::isMountPointAllowed(const QString &mountPoint) const
         return false;
     }
 
-    bool mountPointOk = false;
-
-#if defined(Q_OS_LINUX)
-    QList<QStorageInfo> mountedVolumes = QStorageInfo::mountedVolumes();
-
-    for (const QStorageInfo &volume : std::as_const(mountedVolumes)) {
-        if (volume.fileSystemType() != "cifs" && volume.fileSystemType() != "smb3") {
-            continue;
-        }
-
-        if (canonicalMountPoint == QDir(volume.rootPath()).canonicalPath()) {
-            mountPointOk = true;
-            break;
-        }
-    }
-#elif defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
-    // Under FreeBSD, QStorageInfo does not return 'smbfs' filesystems, so
-    // we need to use the getmntinfo() approach.
-    struct statfs *filesystems = nullptr;
-    int number = getmntinfo(&filesystems, MNT_NOWAIT);
-
-    if (number > 0) {
-        for (int i = 0; i < number; i++) {
-            if (QString::fromUtf8(filesystems[i].f_fstypename) != QStringLiteral("smbfs")) {
-                continue;
-            }
-
-            if (canonicalMountPoint == QDir(QString::fromUtf8(filesystems[i].f_mntonname)).canonicalPath()) {
-                mountPointOk = true;
-                break;
-            }
-        }
-    }
-#endif
-
-    return mountPointOk;
+    return true;
 }
 
 bool Smb4KMountHelper::checkFileDescriptor(const QDBusUnixFileDescriptor &dbusFd)
