@@ -10,12 +10,13 @@
 
 // application specific includes
 #include "smb4kconfigpagebookmarks.h"
+#include "smb4kdialogs_export.h"
 
 // Qt includes
 #include <QDialog>
 #include <QPushButton>
 
-class Q_DECL_EXPORT Smb4KBookmarkEditor : public QDialog
+class SMB4KDIALOGS_EXPORT Smb4KBookmarkEditor : public QDialog
 {
     Q_OBJECT
 
